# Modules always contain just 32-bit code
%define _libdir %{_exec_prefix}/lib

# 64bit intel machines use 32bit boot loader
# (We cannot just redefine _target_cpu, as we'd get i386.rpm packages then)
%ifarch x86_64
%define _target_platform i386-%{_vendor}-%{_target_os}%{?_gnu}
%endif

Distribution:	CCux
Packager:	Karsten Brockmann <arcam@ccux-linux.de>

Name:           grub2
Epoch:          1
Version:        1.98
Release:      	1
Summary:        Bootloader with support for Linux, Multiboot and more

Group:          System Environment/Base
License:        GPLv3+
URL:            http://www.gnu.org/software/grub/
Source0:        ftp://alpha.gnu.org/gnu/grub/grub-%{version}.tar.gz
Source1:        90_persistent
Source2:        grub.default
Patch0:         grub-1.95-grubdir.patch
Patch1:		grub2-python26.patch
Patch2:         grub-1.97.1-initramfs.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:	i686

BuildRequires:  flex bison ruby binutils
BuildRequires:  ncurses-devel lzo-devel
BuildRequires:  libusb-devel
BuildRequires:  autoconf automake
BuildRequires:	texinfo
BuildRequires:  unifont
BuildRequires:  diffutils

ExclusiveArch:  %{ix86} x86_64

#Automatically resolved build dependencies
BuildRequires: freetype-devel
BuildRequires: glibc-devel
BuildRequires: zlib-devel

%description
This is the second version of the GRUB (Grand Unified Bootloader),
a highly configurable and customizable bootloader with modular
architecture.  It support rich scale of kernel formats, file systems,
computer architectures and hardware devices.

PLEASE NOTE: This is a development snapshot, and as such will not
replace grub if you install it, but will be merely added as another
kernel to your existing GRUB menu. Do not replace GRUB (grub package)
with it unless you know what are you doing.


%prep
%setup -q -n grub-%{version}

%patch0 -p1 -b .grubdir
%patch1 -p1 -b .python
%patch2 -p1 -b .initramfs

%build
sh autogen.sh
# -static is needed so that autoconf script is able to link
# test that looks for _start symbol on 64 bit platforms
%configure TARGET_LDFLAGS=-static       \
        --with-platform=pc              \
        --program-transform-name=s,grub,%{name}, \
	--enable-grub-emu-usb \
	--enable-grub-emu-sdl \
	--enable-grub-emu-pci

make %{?_smp_mflags}

%install
set -e
rm -fr $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

# Script that makes part of grub.cfg persist across updates
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/grub.d/

# Ghost config file
install -d $RPM_BUILD_ROOT/boot/%{name}
touch $RPM_BUILD_ROOT/boot/%{name}/grub.cfg
ln -s ../boot/%{name}/grub.cfg $RPM_BUILD_ROOT%{_sysconfdir}/%{name}.cfg

# Install ELF files modules and images were created from into
# the shadow root, where debuginfo generator will grab them from
find $RPM_BUILD_ROOT -name '*.mod' -o -name '*.img' |
while read MODULE
do
        BASE=$(echo $MODULE |sed -r "s,.*/([^/]*)\.(mod|img),\1,")
        # Symbols from .img files are in .exec files, while .mod
        # modules store symbols in .elf. This is just because we
        # have both boot.img and boot.mod ...
        EXT=$(echo $MODULE |grep -q '.mod' && echo '.elf' || echo '.exec')
        TGT=$(echo $MODULE |sed "s,$RPM_BUILD_ROOT,.debugroot,")
#        install -m 755 -D $BASE$EXT $TGT
done

# Defaults
install -m 644 -D %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/default/grub

rm -rf $RPM_BUILD_ROOT/usr/share/info/dir

%clean    
rm -rf $RPM_BUILD_ROOT


%post
exec >/dev/null 2>&1
# Create device.map or reuse one from GRUB Legacy
cp -u /boot/grub/device.map /boot/%{name}/device.map 2>/dev/null ||
        %{name}-mkdevicemap
# Determine the partition with /boot
BOOT_PARTITION=$(df -h /boot |(read; awk '{print $1; exit}'))
# Generate core.img, but don't let it be installed in boot sector
%{name}-install --grub-setup=/bin/true $BOOT_PARTITION
# Remove stale menu.lst entries
#/sbin/grubby --remove-kernel=/boot/%{name}/core.img
# Add core.img as multiboot kernel to GRUB Legacy menu
#/sbin/grubby --add-kernel=/boot/%{name}/core.img --title="GNU GRUB 2, (%{version})"


%preun
exec >/dev/null
#/sbin/grubby --remove-kernel=/boot/%{name}/core.img
# XXX Ugly
rm -f /boot/%{name}/*.mod
rm -f /boot/%{name}/*.img
rm -f /boot/%{name}/*.lst
rm -f /boot/%{name}/device.map


%triggerin -- kernel, kernel-PAE, kernel-BFS. kernel-BFS-PAE
exec >/dev/null 2>&1
# Generate grub.cfg
%{name}-mkconfig


%triggerun -- kernel, kernel-PAE, kernel-BFS. kernel-BFS-PAE
exec >/dev/null 2>&1
# Generate grub.cfg
%{name}-mkconfig


%files
%defattr(-,root,root,-)
%{_libdir}/%{name}
%{_libdir}/grub/
%{_sbindir}/%{name}-mkdevicemap
%{_sbindir}/%{name}-install
#%{_sbindir}/%{name}-emu
%{_sbindir}/%{name}-probe
%{_sbindir}/%{name}-setup
%{_sbindir}/%{name}-mkconfig
%{_bindir}/%{name}-mkimage
%{_bindir}/%{name}-mkelfimage
%{_bindir}/%{name}-editenv
%{_bindir}/%{name}-fstest
%{_bindir}/%{name}-mkfont
%{_bindir}/%{name}-mkrescue
%{_bindir}/grub2-bin2h
%{_bindir}/grub2-mkisofs
%{_bindir}/grub2-mkpasswd-pbkdf2
%{_bindir}/grub2-mkrelpath
%{_bindir}/grub2-script-check
%{_sbindir}/grub2-reboot
%{_sbindir}/grub2-set-default
%{_locale}/*/LC_MESSAGES/grub.mo
%dir %{_sysconfdir}/grub.d
%config %{_sysconfdir}/grub.d/??_*
%{_sysconfdir}/grub.d/README
%{_sysconfdir}/%{name}.cfg
%{_sysconfdir}/default/grub
%dir /boot/%{name}
# Actually, this is replaced by update-grub from scriptlets,
# but it takes care of modified persistent part
%config(noreplace) /boot/%{name}/grub.cfg
%doc COPYING INSTALL NEWS README THANKS TODO ChangeLog

# prevent clash with grub legacy
#
%exclude %{_infodir}/grub.info.gz

%{_datadir}/grub2/ascii.h
%{_datadir}/grub2/ascii.pf2
%{_datadir}/grub2/unicode.pf2

%changelog
* Mon Mar 08 2010 Karsten Brockmann <arcam@ccux-linux.de> 1.98-1
- initial CCux package release
